@@ -1,5 +1,5 @@
 package CloudFlare::Client;
-# ABSTRACT: Object Orientated Interface to Cloudflare client API
+# ABSTRACT: Object Orientated Interface to CloudFlare client API
 
 use Modern::Perl '2012';
 use autodie ':all';
@@ -16,7 +16,7 @@ use CloudFlare::Client::Exception::Upstream;
 use LWP::UserAgent;
 use JSON::Any;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 # Read only attributes
 # Cloudflare credentials
@@ -24,31 +24,25 @@ has '_user' => (
     is       => 'ro',
     isa      => 'Str',
     required => 1,
-    init_arg => 'user'
-    );
+    init_arg => 'user');
 has '_key' => (
     is       => 'ro',
     isa      => 'Str',
     required => 1,
-    init_arg => 'apikey'
-    );
+    init_arg => 'apikey');
 Readonly my $UA_STRING =>
     "CloudFlare::Client/$CloudFlare::Client::VERSION";
 has '_ua' => (
     is       => 'ro',
-    default  => sub {
-        Readonly my $ua => LWP::UserAgent->new;
-        $ua->agent($UA_STRING);
-        $ua
-    },
-    init_arg => undef
-    );
+    default  => sub { Readonly my $ua => LWP::UserAgent::->new;
+                      $ua->agent($UA_STRING);
+                      $ua},
+    init_arg => undef);
 
 # private methods
 Readonly my $CF_URL =>
     'https://www.cloudflare.com/api_json.html';
-method _apiCall($act is ro,
-                %args is ro) {
+method _apiCall($act is ro, %args is ro) {
     # query cloudflare
     Readonly my $res => $self->_ua->post($CF_URL, {
         %args,
@@ -56,176 +50,106 @@ method _apiCall($act is ro,
         # override user specified
         tkn   => $self->_key,
         email => $self->_user,
-        a     => $act
-                                         });
-    throw CloudFlare::Client::Exception::Connection(
+        a     => $act});
+    CloudFlare::Client::Exception::Connection::->throw(
         status  => $res->status_line,
-        message => 'HTTPS request failed'
-        ) unless $res->is_success;
+        message => 'HTTPS request failed')
+        unless $res->is_success;
     Readonly my $info =>
-        JSON::Any->jsonToObj($res->decoded_content);
-    throw CloudFlare::Client::Exception::Upstream(
+        JSON::Any::->jsonToObj($res->decoded_content);
+    CloudFlare::Client::Exception::Upstream::->throw(
         errorCode => $info->{err_code},
-        message   => $info->{msg}
-        ) unless $info->{result} eq 'success';
+        message   => $info->{msg})
+        unless $info->{result} eq 'success';
 
-    $info->{response}
-}
+    $info->{response}}
 
 # Methods
-method stats($zone  is ro,
-             $itrvl is ro) {
-    $self->_apiCall('stats',
-                    z        => $zone,
-                    interval => $itrvl);
-}
+method stats($zone  is ro, $itrvl is ro) {
+    $self->_apiCall('stats', z => $zone, interval => $itrvl)}
 
 method zoneLoadMulti {
-    $self->_apiCall('zone_load_multi');
-}
+    $self->_apiCall('zone_load_multi')}
 
 method recLoadAll($zone is ro) {
-    $self->_apiCall('rec_load_all',
-                    z => $zone);
-}
+    $self->_apiCall('rec_load_all', z => $zone)}
 
-method zoneCheck(@zones is ro) {
-    $self->_apiCall('zone_check',
-                    zones => join ',', @zones);
-}
+# Requires at least one zone, but can take any number
+method zoneCheck($fZone is ro, @rZones is ro) {
+    $self->_apiCall('zone_check', zones => join ',', $fZone, @rZones)}
 
 method zoneIps($zone is ro, %args is ro) {
-    $self->_apiCall('zone_ips',
-                    %args,
+    $self->_apiCall('zone_ips', %args,
                     # Override user specified
-                    z     => $zone);
-}
+                    z     => $zone)}
 
 method ipLkup($ip is ro) {
-    $self->_apiCall('ip_lkup',
-                    ip => $ip);
-}
+    $self->_apiCall('ip_lkup', ip => $ip)}
 
 method zoneSettings($zone is ro) {
-    $self->_apiCall('zone_settings',
-                    z => $zone);
-}
+    $self->_apiCall('zone_settings', z => $zone)}
 
 method secLvl($zone is ro, $secLvl is ro) {
-    $self->_apiCall('sec_lvl',
-                    z => $zone,
-                    v => $secLvl);
+    $self->_apiCall('sec_lvl', z => $zone, v => $secLvl);
 }
 
 method cacheLvl($zone is ro, $cchLvl is ro) {
-    $self->_apiCall('cache_lvl',
-                    z => $zone,
-                    v => $cchLvl);
-}
+    $self->_apiCall('cache_lvl', z => $zone, v => $cchLvl)}
 
 method devMode($zone is ro, $val is ro) {
-    $self->_apiCall('devmode',
-                    z => $zone,
-                    v => $val);
-}
+    $self->_apiCall('devmode', z => $zone, v => $val)}
 
 method fpurgeTs($zone is ro, $val is ro) {
-    $self->_apiCall('fpurge_ts',
-                    z => $zone,
-                    v => $val);
-}
+    $self->_apiCall('fpurge_ts', z => $zone, v => $val)}
 
 method zoneFilePurge($zone is ro, $url is ro) {
-    $self->_apiCall('zone_file_purge',
-                    z   => $zone,
-                    url => $url)
-}
+    $self->_apiCall('zone_file_purge', z => $zone, url => $url)}
 
 method zoneGrab($zId is ro) {
-    $self->_apiCall('zone_grab',
-                    zid => $zId)
-}
+    $self->_apiCall('zone_grab', zid => $zId)}
 
 method _wlBanNul($act is ro, $ip is ro) {
-    $self->_apiCall($act,
-                    key => $ip);
-}
+    $self->_apiCall($act, key => $ip)}
 
 method wl($ip is ro) {
-    $self->_wlBanNul('wl', $ip);
-}
+    $self->_wlBanNul('wl', $ip)}
 
 method ban($ip is ro) {
-    $self->_wlBanNul('ban', $ip);
-}
+    $self->_wlBanNul('ban', $ip)}
 
 method nul($ip is ro) {
-    $self->_wlBanNul('nul', $ip);
-}
+    $self->_wlBanNul('nul', $ip)}
 
 method ipv46($zone is ro, $val is ro) {
-    $self->_apiCall('ipv46',
-                    z => $zone,
-                    v => $val)
-}
+    $self->_apiCall('ipv46', z => $zone, v => $val)}
 
 method async($zone is ro, $val is ro) {
-    $self->_apiCall('async',
-                    z => $zone,
-                    v => $val)
-}
+    $self->_apiCall('async', z => $zone, v => $val)}
 
 method minify($zone is ro, $val is ro) {
-    $self->_apiCall('async',
-                    z => $zone,
-                    v => $val);
-}
+    $self->_apiCall('async', z => $zone, v => $val)}
 
 method mirage2($zone is ro, $val is ro) {
-    $self->_apiCall('mirage2',
-                    z => $zone,
-                    v => $val)
-}
+    $self->_apiCall('mirage2', z => $zone, v => $val)}
 
-method recNew($zone  is ro,
-              $type  is ro,
-              $name  is ro,
-              $cntnt is ro,
-              $ttl   is ro,
-              %args  is ro) {
+method recNew($zone is ro, $type is ro, $name is ro, $cntnt is ro,
+              $ttl is ro, %args is ro) {
     $self->_apiCall('rec_new',
                     %args,
                     # Override user specified
-                    z       => $zone,
-                    type    => $type,
-                    name    => $name,
-                    content => $cntnt,
-                    ttl     => $ttl);
-}
+                    z => $zone, type => $type, name => $name,
+                    content => $cntnt, ttl => $ttl)}
 
-method recEdit($zone  is ro,
-               $type  is ro,
-               $id    is ro,
-               $name  is ro,
-               $cntnt is ro,
-               $ttl   is ro,
-               %args  is ro) {
+method recEdit($zone is ro, $type is ro, $id is ro, $name is ro, $cntnt is ro,
+               $ttl is ro, %args  is ro) {
     $self->_apiCall('rec_edit',
                     %args,
                     # override user specified
-                    z => $zone,
-                    type => $type,
-                    id => $id,
-                    name => $name,
-                    content => $cntnt,
-                    ttl     => $ttl)
-}
+                    z => $zone, type => $type, id => $id, name => $name,
+                    content => $cntnt, ttl => $ttl)}
 
 method recDelete($zone is ro, $id is ro) {
-    $self->_apiCall('rec_delete',
-                    z  => $zone,
-                    id => $id);
-}
+    $self->_apiCall('rec_delete', z => $zone, id => $id)}
 
 __PACKAGE__->meta->make_immutable;
 1; # End of CloudFlare::Client
@@ -238,11 +162,11 @@ __END__
 
 =head1 NAME
 
-CloudFlare::Client - Object Orientated Interface to Cloudflare client API
+CloudFlare::Client - Object Orientated Interface to CloudFlare client API
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -250,7 +174,7 @@ Provides an object orientated interface to the CloudFlare client API
 
     use CloudFlare::Client;
 
-    my $api = new CloudFlare::Client(
+    my $api = CloudFlare::Client::->new(
         user   => $CF_USER,
         apikey => $CF_KEY);
     $api->stats;
@@ -261,6 +185,8 @@ L<https://www.cloudflare.com/docs/client-api.html> for information the
 CloudFlare client API and its arguments. Optional arguments are passed
 in as a hash with keys as given in the docs
 
+Successful API calls return the response section from the upstream JSON API. Failures for whatever reason throw exceptions under the CloudFlare::Client::Exception:: namespace
+
 =head1 ATTRIBUTES
 
 =head2 _user
@@ -283,9 +209,9 @@ UserAgent object used to make API calls, set internally. Readonly
 
 Construct a new CloudFlare::Client API object
 
-    my $api = new CloudFlare::Client(
+    my $api = CloudFlare::Client::->new(
         user   => $CF_USER,
-        apikey => $CF_KEY);
+        apikey => $CF_KEY)
 
 =head2 stats
 
@@ -317,7 +243,7 @@ Construct a new CloudFlare::Client API object
 
 =head2 secLvl
 
-    $api->secLvl($zone,$securityLvl)
+    $api->secLvl($zone, $securityLvl)
 
 =head2 cacheLvl
 
